==> immersiveoverlays-1.4.2%2B1.19.2-fabric-sources.jar: cc/cassian/immersiveoverlays/helpers/ModLists.java <==
package cc.cassian.immersiveoverlays.helpers;

import cc.cassian.immersiveoverlays.config.ModConfig;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import net.minecraft.class_1792;
import net.minecraft.class_2348;
import net.minecraft.class_2378;
import net.minecraft.class_2960;

public class ModLists {
    public static ArrayList<class_1792> compass_x_items = new ArrayList<>();
    public static ArrayList<class_1792> compass_y_items = new ArrayList<>();
    public static ArrayList<class_1792> compass_z_items = new ArrayList<>();
    public static ArrayList<class_1792> clock_items = new ArrayList<>();
    public static ArrayList<class_1792> weather_items = new ArrayList<>();
    public static ArrayList<class_1792> biome_items = new ArrayList<>();
    public static ArrayList<class_1792> season_items = new ArrayList<>();
    public static ArrayList<class_1792> temperature_items = new ArrayList<>();
    public static ArrayList<class_1792> speed_items = new ArrayList<>();
    public static ArrayList<class_1792> waila_items = new ArrayList<>();


    public static void loadLists() {
        //? if >1.20 {
        /*var registry = BuiltInRegistries.ITEM;
        *///?} else {
        var registry = class_2378.field_11142;
         //?}
        addAll(registry, ModConfig.get().compass_x_items, compass_x_items);
        addAll(registry, ModConfig.get().compass_y_items, compass_y_items, compass_x_items);
        addAll(registry, ModConfig.get().compass_z_items, compass_z_items, compass_x_items);
        addAll(registry, ModConfig.get().clock_items, clock_items);
        addAll(registry, ModConfig.get().biome_items, biome_items, compass_x_items);
        addAll(registry, ModConfig.get().clock_weather_items, weather_items, clock_items);
        addAll(registry, ModConfig.get().season_items, season_items);
        addAll(registry, ModConfig.get().temperature_items, temperature_items);
        addAll(registry, ModConfig.get().speed_items, speed_items);
        addAll(registry, ModConfig.get().compat_waila_items, waila_items);
    }

    private static void addAll(class_2348<class_1792> registry, List<String> idList, ArrayList<class_1792> itemList) {
        itemList.clear();
        for (String itemId : idList) {
            Optional<class_1792> item = registry.method_17966(class_2960.method_12829(itemId));
            item.ifPresent(itemList::add);
        }
    }

    private static void addAll(class_2348<class_1792> registry, List<String> idList, ArrayList<class_1792> itemList, ArrayList<class_1792> fallbackList) {
        addAll(registry, idList, itemList);
        if (itemList.isEmpty()) {
            itemList.addAll(fallbackList);
        }
    }

}

==> immersiveoverlays-1.4.4%2B1.21.1-fabric-sources.jar: cc/cassian/immersiveoverlays/helpers/ModLists.java <==
package cc.cassian.immersiveoverlays.helpers;

import cc.cassian.immersiveoverlays.config.ModConfig;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import net.minecraft.class_1792;
import net.minecraft.class_2960;
import net.minecraft.class_7922;
import net.minecraft.class_7923;

public class ModLists {
    public static ArrayList<class_1792> compass_x_items = new ArrayList<>();
    public static ArrayList<class_1792> compass_y_items = new ArrayList<>();
    public static ArrayList<class_1792> compass_z_items = new ArrayList<>();
    public static ArrayList<class_1792> clock_items = new ArrayList<>();
    public static ArrayList<class_1792> weather_items = new ArrayList<>();
    public static ArrayList<class_1792> biome_items = new ArrayList<>();
    public static ArrayList<class_1792> season_items = new ArrayList<>();
    public static ArrayList<class_1792> temperature_items = new ArrayList<>();
    public static ArrayList<class_1792> speed_items = new ArrayList<>();
    public static ArrayList<class_1792> waila_items = new ArrayList<>();


    public static void loadLists() {
        //? if >1.20 {
        var registry = class_7923.field_41178;
        //?} else {
        /*var registry = Registry.ITEM;
         *///?}
        addAll(registry, ModConfig.get().compass_x_items, compass_x_items);
        addAll(registry, ModConfig.get().compass_y_items, compass_y_items, compass_x_items);
        addAll(registry, ModConfig.get().compass_z_items, compass_z_items, compass_x_items);
        addAll(registry, ModConfig.get().clock_items, clock_items);
        addAll(registry, ModConfig.get().biome_items, biome_items, compass_x_items);
        addAll(registry, ModConfig.get().clock_weather_items, weather_items, clock_items);
        addAll(registry, ModConfig.get().season_items, season_items);
        addAll(registry, ModConfig.get().temperature_items, temperature_items);
        addAll(registry, ModConfig.get().speed_items, speed_items);
        addAll(registry, ModConfig.get().compat_waila_items, waila_items);
    }

    private static void addAll(class_7922<class_1792> registry, List<String> idList, ArrayList<class_1792> itemList) {
        itemList.clear();
        for (String itemId : idList) {
            Optional<class_1792> item = registry.method_17966(class_2960.method_12829(itemId));
            item.ifPresent(itemList::add);
        }
    }

    private static void addAll(class_7922<class_1792> registry, List<String> idList, ArrayList<class_1792> itemList, ArrayList<class_1792> fallbackList) {
        addAll(registry, idList, itemList);
        if (itemList.isEmpty()) {
            itemList.addAll(fallbackList);
        }
    }

}
